FireStoreCollection class

todo: This has to be split up to a parent class.

Constructors

FireStoreCollection(String path)
Provide the 'path' of the Firebase database.

Properties

collection → CollectionReference<Object?>?
The Collection Reference object.
no setter
ex ← Exception
Assign an Exception object.
no getter
hashCode → int
The hash code for this object.
no setterinherited
inError → bool
Indicator if in error.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uid → String
The User id
no setter

Methods

add(Map<String, dynamic> data) → Future<String>
Add the provided Map object.
currentUser() → Future<User?>
The current user. No longer async operation but we'll keep it backward-compatible.
delete(String? docId) → Future<bool>
Delete the Firebase entry by its String Id.
getError([Object? ex]) → Exception
Return the current Exception object.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
runTransaction(TransactionHandler transactionHandler, {Duration timeout = const Duration(seconds: 10)}) → Future<Map<String, dynamic>>
Doubled the attempt duration to 10 seconds.
setError(Object ex) → Exception
Assign an Exception object.
toString() → String
A string representation of this object.
inherited
update(String path, Map<String, dynamic> data) → Future<bool>
Update the Firebase path with the provided Map object.

Operators

operator ==(Object other) → bool
The equality operator.
inherited